==> qtjambi-serialbus-debuginfo-linux-x64-5.15.17.jar: sources/QtJambiSerialBus/QCanBusFrame_TimeStamp_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtSerialBus/qcanbusframe.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambiSerialBus/hashes.h>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QCanBusFrame_TimeStamp(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QCanBusFrame::TimeStamp")
    QCanBusFrame::TimeStamp *_ptr = reinterpret_cast<QCanBusFrame::TimeStamp *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new TimeStamp(qint64,qint64)
void __qt_construct_QCanBusFrame_TimeStamp_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct TimeStamp(qint64,qint64)")
    Q_UNUSED(__java_arguments)
    QCanBusFrame::TimeStamp *__qt_this = new(__qtjambi_ptr) QCanBusFrame::TimeStamp();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// new TimeStamp(qint64,qint64)
void __qt_construct_QCanBusFrame_TimeStamp_1(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct TimeStamp(qint64,qint64)")
    jlong s0 = __java_arguments[0].j;
    Q_UNUSED(s0)
    QCanBusFrame::TimeStamp *__qt_this = new(__qtjambi_ptr) QCanBusFrame::TimeStamp(static_cast<qint64>(s0));
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// new TimeStamp(qint64,qint64)
void __qt_construct_QCanBusFrame_TimeStamp_2(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct TimeStamp(qint64,qint64)")
    jlong s0 = __java_arguments[0].j;
    Q_UNUSED(s0)
    jlong usec1 = __java_arguments[1].j;
    Q_UNUSED(usec1)
    QCanBusFrame::TimeStamp *__qt_this = new(__qtjambi_ptr) QCanBusFrame::TimeStamp(static_cast<qint64>(s0), static_cast<qint64>(usec1));
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// destruct QCanBusFrame::TimeStamp
void __qt_destruct_QCanBusFrame_TimeStamp(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QCanBusFrame::TimeStamp")
    reinterpret_cast<QCanBusFrame::TimeStamp*>(ptr)->~TimeStamp();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QCanBusFrame::TimeStamp::TimeStamp(qint64,qint64)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_serialbus_QCanBusFrame_00024TimeStamp_initialize_1native__Lio_qt_serialbus_QCanBusFrame_00024TimeStamp_2JJ)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jlong s0,
 jlong usec1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QCanBusFrame::TimeStamp::TimeStamp(qint64,qint64)")
    QTJAMBI_TRY {
        jvalue arguments[2];
        arguments[0].j = s0;
        arguments[1].j = usec1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QCanBusFrame_TimeStamp_2, sizeof(QCanBusFrame::TimeStamp), typeid(QCanBusFrame::TimeStamp), false, &deleter_QCanBusFrame_TimeStamp, arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QCanBusFrame::TimeStamp::microSeconds()const
extern "C" Q_DECL_EXPORT jlong JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_serialbus_QCanBusFrame_00024TimeStamp_microSeconds_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jlong __java_return_value{0};
    QTJAMBI_TRY {
        const QCanBusFrame::TimeStamp *__qt_this = QtJambiAPI::objectFromNativeId<QCanBusFrame::TimeStamp>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QCanBusFrame::TimeStamp::microSeconds()const", __qt_this)
        qint64 __qt_return_value = __qt_this->microSeconds();
        __java_return_value = jlong(__qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QCanBusFrame::TimeStamp::operator==(QCanBusFrame::TimeStamp,QCanBusFrame::TimeStamp)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_serialbus_QCanBusFrame_00024TimeStamp_operator_1equal_1native_1cref_1QCanBusFrame_1TimeStamp__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID value21)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QCanBusFrame::TimeStamp *__qt_this = QtJambiAPI::objectFromNativeId<QCanBusFrame::TimeStamp>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QCanBusFrame::TimeStamp::operator==(QCanBusFrame::TimeStamp,QCanBusFrame::TimeStamp)", __qt_this)
        const QCanBusFrame::TimeStamp& __qt_value21 = QtJambiAPI::valueReferenceFromNativeId<QCanBusFrame::TimeStamp>(value21);
        __java_return_value = (*__qt_this) == __qt_value21;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QCanBusFrame::TimeStamp::seconds()const
extern "C" Q_DECL_EXPORT jlong JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_serialbus_QCanBusFrame_00024TimeStamp_seconds_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jlong __java_return_value{0};
    QTJAMBI_TRY {
        const QCanBusFrame::TimeStamp *__qt_this = QtJambiAPI::objectFromNativeId<QCanBusFrame::TimeStamp>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QCanBusFrame::TimeStamp::seconds()const", __qt_this)
        qint64 __qt_return_value = __qt_this->seconds();
        __java_return_value = jlong(__qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QCanBusFrame::TimeStamp::fromMicroSeconds(qint64)
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_serialbus_QCanBusFrame_00024TimeStamp_fromMicroSeconds__J)
(JNIEnv *__jni_env,
 jclass,
 jlong usec0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QCanBusFrame::TimeStamp::fromMicroSeconds(qint64)")
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        QCanBusFrame::TimeStamp __qt_return_value = QCanBusFrame::TimeStamp::fromMicroSeconds(static_cast<qint64>(usec0));
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_serialbus_QCanBusFrame_00024TimeStamp_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QCanBusFrame::TimeStamp *__qt_this = QtJambiAPI::objectFromNativeId<QCanBusFrame::TimeStamp>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(hashValue);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_serialbus_QCanBusFrame_00024TimeStamp_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QCanBusFrame::TimeStamp *__qt_this = QtJambiAPI::objectFromNativeId<QCanBusFrame::TimeStamp>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QCanBusFrame_TimeStamp(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QCanBusFrame::TimeStamp>("QCanBusFrame::TimeStamp", "io/qt/serialbus/QCanBusFrame$TimeStamp");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QCanBusFrame_TimeStamp, {
        ConstructorInfo(&__qt_construct_QCanBusFrame_TimeStamp_0, nullptr)
       ,ConstructorInfo(&__qt_construct_QCanBusFrame_TimeStamp_1, "J")
       ,ConstructorInfo(&__qt_construct_QCanBusFrame_TimeStamp_2, "JJ")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QCanBusFrame_TimeStamp);
    registerMetaType<QCanBusFrame::TimeStamp>("QCanBusFrame::TimeStamp");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-serialbus-debuginfo-linux-x64-6.5.4.jar: sources/QtJambiSerialBus/QCanBusFrame_TimeStamp_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtSerialBus/qcanbusframe.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambiSerialBus/hashes.h>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QCanBusFrame_TimeStamp(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QCanBusFrame::TimeStamp")
    QCanBusFrame::TimeStamp *_ptr = reinterpret_cast<QCanBusFrame::TimeStamp *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new TimeStamp(qint64,qint64)
void __qt_construct_QCanBusFrame_TimeStamp_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct TimeStamp(qint64,qint64)")
    Q_UNUSED(__java_arguments)
    QCanBusFrame::TimeStamp *__qt_this = new(__qtjambi_ptr) QCanBusFrame::TimeStamp();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// new TimeStamp(qint64,qint64)
void __qt_construct_QCanBusFrame_TimeStamp_1(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct TimeStamp(qint64,qint64)")
    jlong s0 = __java_arguments[0].j;
    Q_UNUSED(s0)
    QCanBusFrame::TimeStamp *__qt_this = new(__qtjambi_ptr) QCanBusFrame::TimeStamp(static_cast<qint64>(s0));
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// new TimeStamp(qint64,qint64)
void __qt_construct_QCanBusFrame_TimeStamp_2(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct TimeStamp(qint64,qint64)")
    jlong s0 = __java_arguments[0].j;
    Q_UNUSED(s0)
    jlong usec1 = __java_arguments[1].j;
    Q_UNUSED(usec1)
    QCanBusFrame::TimeStamp *__qt_this = new(__qtjambi_ptr) QCanBusFrame::TimeStamp(static_cast<qint64>(s0), static_cast<qint64>(usec1));
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// destruct QCanBusFrame::TimeStamp
void __qt_destruct_QCanBusFrame_TimeStamp(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QCanBusFrame::TimeStamp")
    reinterpret_cast<QCanBusFrame::TimeStamp*>(ptr)->~TimeStamp();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QCanBusFrame::TimeStamp::TimeStamp(qint64,qint64)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_serialbus_QCanBusFrame_00024TimeStamp_initialize_1native__Lio_qt_serialbus_QCanBusFrame_00024TimeStamp_2JJ)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jlong s0,
 jlong usec1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QCanBusFrame::TimeStamp::TimeStamp(qint64,qint64)")
    QTJAMBI_TRY {
        jvalue arguments[2];
        arguments[0].j = s0;
        arguments[1].j = usec1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QCanBusFrame_TimeStamp_2, sizeof(QCanBusFrame::TimeStamp), typeid(QCanBusFrame::TimeStamp), false, &deleter_QCanBusFrame_TimeStamp, arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QCanBusFrame::TimeStamp::microSeconds()const
extern "C" Q_DECL_EXPORT jlong JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_serialbus_QCanBusFrame_00024TimeStamp_microSeconds_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jlong __java_return_value{0};
    QTJAMBI_TRY {
        const QCanBusFrame::TimeStamp *__qt_this = QtJambiAPI::objectFromNativeId<QCanBusFrame::TimeStamp>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QCanBusFrame::TimeStamp::microSeconds()const", __qt_this)
        qint64 __qt_return_value = __qt_this->microSeconds();
        __java_return_value = jlong(__qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QCanBusFrame::TimeStamp::operator==(QCanBusFrame::TimeStamp,QCanBusFrame::TimeStamp)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_serialbus_QCanBusFrame_00024TimeStamp_equals_1native_1cref_1QCanBusFrame_1TimeStamp__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID value21)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QCanBusFrame::TimeStamp *__qt_this = QtJambiAPI::objectFromNativeId<QCanBusFrame::TimeStamp>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QCanBusFrame::TimeStamp::operator==(QCanBusFrame::TimeStamp,QCanBusFrame::TimeStamp)", __qt_this)
        const QCanBusFrame::TimeStamp& __qt_value21 = QtJambiAPI::valueReferenceFromNativeId<QCanBusFrame::TimeStamp>(value21);
        __java_return_value = (*__qt_this) == __qt_value21;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QCanBusFrame::TimeStamp::seconds()const
extern "C" Q_DECL_EXPORT jlong JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_serialbus_QCanBusFrame_00024TimeStamp_seconds_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jlong __java_return_value{0};
    QTJAMBI_TRY {
        const QCanBusFrame::TimeStamp *__qt_this = QtJambiAPI::objectFromNativeId<QCanBusFrame::TimeStamp>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QCanBusFrame::TimeStamp::seconds()const", __qt_this)
        qint64 __qt_return_value = __qt_this->seconds();
        __java_return_value = jlong(__qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QCanBusFrame::TimeStamp::fromMicroSeconds(qint64)
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_serialbus_QCanBusFrame_00024TimeStamp_fromMicroSeconds__J)
(JNIEnv *__jni_env,
 jclass,
 jlong usec0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QCanBusFrame::TimeStamp::fromMicroSeconds(qint64)")
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        QCanBusFrame::TimeStamp __qt_return_value = QCanBusFrame::TimeStamp::fromMicroSeconds(static_cast<qint64>(usec0));
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_serialbus_QCanBusFrame_00024TimeStamp_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QCanBusFrame::TimeStamp *__qt_this = QtJambiAPI::objectFromNativeId<QCanBusFrame::TimeStamp>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(quint64(hashValue) ^ quint64(hashValue) >> 32);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_serialbus_QCanBusFrame_00024TimeStamp_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QCanBusFrame::TimeStamp *__qt_this = QtJambiAPI::objectFromNativeId<QCanBusFrame::TimeStamp>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QCanBusFrame_TimeStamp(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QCanBusFrame::TimeStamp>("QCanBusFrame::TimeStamp", "io/qt/serialbus/QCanBusFrame$TimeStamp");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QCanBusFrame_TimeStamp, {
        ConstructorInfo(&__qt_construct_QCanBusFrame_TimeStamp_0, nullptr)
       ,ConstructorInfo(&__qt_construct_QCanBusFrame_TimeStamp_1, "J")
       ,ConstructorInfo(&__qt_construct_QCanBusFrame_TimeStamp_2, "JJ")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QCanBusFrame_TimeStamp);
    registerMetaType<QCanBusFrame::TimeStamp>("QCanBusFrame::TimeStamp");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
